@@ -69,13 +69,26 @@ where
 ///
 /// Every module supplies an implementation of it self
 /// on this type.
-pub struct Cpo<DB> {
+#[derive(Clone)]
+pub struct Cpo<DB>
+where
+    DB: Store,
+{
     base_url: Url,
     db: DB,
     client: Client,
 }
 
-impl<DB> Cpo<DB> {
+impl<DB> Cpo<DB>
+where
+    DB: Store,
+{
+    /// Creates a new Cpo instance.
+    /// the base_url must be the url to the base ocpi endpoint.
+    /// __NOT__ the versions module.
+    /// This base url will be used to add on each module url.
+    /// so `versions` will be appended and the versions module
+    /// should be served from that path.
     pub fn new(base_url: Url, db: DB, client: Client) -> Self {
         Self {
             base_url,
@@ -85,10 +98,16 @@ impl<DB> Cpo<DB> {
     }
 }
 
-pub trait Store {}
+pub trait Store
+where
+    Self: Clone,
+{
+}
 
 #[cfg(test)]
 pub(crate) fn cpo() -> Cpo<()> {
+    impl Store for () {}
+
     let base_url = "http://localhost".parse().expect("Parsing localhost url");
     Cpo {
         base_url,
